@@ -94,7 +94,7 @@ const basic & basic::operator=(const basic & other)
 //////////
 
 /** Construct object from archive_node. */
-basic::basic(const archive_node &n, lst&) : flags(0)
+basic::basic(const archive_node &n, lst& /*unused*/) : flags(0)
 {
 	// Reconstruct tinfo_key from class name
 	std::string found_class_name;
@@ -149,14 +149,14 @@ next_context:
 
 		// Method not found, try parent print_context class
 		const print_context_class_info * parent_pc_info = pc_info->get_parent();
-		if (parent_pc_info) {
+		if (parent_pc_info != nullptr) {
 			pc_info = parent_pc_info;
 			goto next_context;
 		}
 
 		// Method still not found, try parent class
 		const registered_class_info * parent_reg_info = reg_info->get_parent();
-		if (parent_reg_info) {
+		if (parent_reg_info != nullptr) {
 			reg_info = parent_reg_info;
 			pc_info = &c.get_class_info();
 			goto next_class;
@@ -177,7 +177,7 @@ next_context:
 }
 
 /** Default output to stream. */
-void basic::do_print(const print_context & c, unsigned) const
+void basic::do_print(const print_context & c, unsigned /*unused*/) const
 {
 	c.s << "[" << class_name() << " object]";
 }
@@ -187,7 +187,7 @@ void basic::do_print_tree(const print_tree & c, unsigned level) const
 {
 	c.s << std::string(level, ' ') << class_name() << " @" << this
 	    << std::hex << ", hash=0x" << hashvalue << ", flags=0x" << flags << std::dec;
-	if (nops())
+	if (nops() != 0u)
 		c.s << ", nops=" << nops();
 	c.s << std::endl;
 	for (size_t i=0; i<nops(); ++i)
@@ -195,7 +195,7 @@ void basic::do_print_tree(const print_tree & c, unsigned level) const
 }
 
 /** Python parsable output to stream. */
-void basic::do_print_python_repr(const print_python_repr & c, unsigned) const
+void basic::do_print_python_repr(const print_python_repr & c, unsigned /*unused*/) const
 {
 	c.s << class_name() << "()";
 }
@@ -230,7 +230,7 @@ unsigned basic::precedence() const
 /** Information about the object.
  *
  *  @see class info_flags */
-bool basic::info(unsigned) const
+bool basic::info(unsigned /*unused*/) const
 {
 	// all possible properties are false for basic objects
 	return false;
@@ -246,13 +246,13 @@ size_t basic::nops() const
 }
 
 /** Return operand/member at position i. */
-ex basic::op(size_t) const
+ex basic::op(size_t /*unused*/) const
 {
 	throw(std::range_error(std::string("basic::op(): ") + class_name() + std::string(" has no operands")));
 }
 
 /** Return modifyable operand/member at position i. */
-ex & basic::let_op(size_t)
+ex & basic::let_op(size_t /*unused*/)
 {
 	ensure_if_modifiable();
 	throw(std::range_error(std::string("basic::let_op(): ") + class_name() + std::string(" has no operands")));
@@ -319,7 +319,7 @@ ex basic::map(map_function & f) const
 		}
 	}
 
-	if (copy) {
+	if (copy != nullptr) {
 		copy->setflag(status_flags::dynallocated);
 		copy->clearflag(status_flags::hash_calculated | status_flags::expanded);
 		return *copy;
@@ -422,7 +422,7 @@ ex basic::collect(const ex & s, bool distributed) const
 }
 
 /** Perform automatic non-interruptive term rewriting rules. */
-ex basic::eval(int) const
+ex basic::eval(int /*unused*/) const
 {
 	// There is nothing to do for basic objects:
 	return hold();
@@ -433,7 +433,7 @@ struct evalf_map_function : public map_function {
 	int level;
 	PyObject* parent;
 	evalf_map_function(int l, PyObject* p) : level(l), parent(p) {}
-	ex operator()(const ex & e) { return evalf(e, level, parent); }
+	ex operator()(const ex & e) override { return evalf(e, level, parent); }
 };
 
 /** Evaluate object numerically. */
@@ -453,23 +453,15 @@ ex basic::evalf(int level, PyObject* parent) const
 	}
 }
 
-/** Function object to be applied by basic::evalm(). */
-struct evalm_map_function : public map_function {
-	ex operator()(const ex & e) { return evalm(e); }
-} map_evalm;
-
 /** Evaluate sums, products and integer powers of matrices. */
 ex basic::evalm() const
 {
-	if (nops() == 0)
-		return *this;
-	else
-		return map(map_evalm);
+	return *this;
 }
 
 /** Function object to be applied by basic::eval_integ(). */
 struct eval_integ_map_function : public map_function {
-	ex operator()(const ex & e) { return eval_integ(e); }
+	ex operator()(const ex & e) override { return eval_integ(e); }
 } map_eval_integ;
 
 /** Evaluate integrals, if result is known. */
@@ -528,7 +520,7 @@ ex basic::scalar_mul_indexed(const ex & self, const numeric & other) const
  *  @param v The complete vector of factors
  *  @return true if the contraction was successful, false otherwise
  *  @see ex::simplify_indexed() */
-bool basic::contract_with(exvector::iterator, exvector::iterator, exvector&) const
+bool basic::contract_with(exvector::iterator /*unused*/, exvector::iterator /*unused*/, exvector& /*unused*/) const
 {
 	// Do nothing
 	return false;
@@ -599,7 +591,7 @@ bool basic::match(const ex & pattern, lst & repl_lst) const
 /** Helper function for subs(). Does not recurse into subexpressions. */
 ex basic::subs_one_level(const exmap & m, unsigned options) const
 {
-	if (options & subs_options::no_pattern) {
+	if ((options & subs_options::no_pattern) != 0u) {
 		const auto& it = m.find(*this);
 		return (it != m.end())? it->second : *this;
 	} else {
@@ -618,7 +610,7 @@ ex basic::subs_one_level(const exmap & m, unsigned options) const
 ex basic::subs(const exmap & m, unsigned options) const
 {
 	size_t num = nops();
-	if (num) {
+	if (num != 0u) {
 
 		// Substitute in subexpressions
 		for (size_t i=0; i<num; i++) {
@@ -662,7 +654,7 @@ ex basic::diff(const symbol & s, unsigned nth) const
 		return ex(*this);
 	
 	// evaluate unevaluated *this before differentiating
-	if (!(flags & status_flags::evaluated))
+	if ((flags & status_flags::evaluated) == 0u)
 		return ex(*this).diff(s, nth);
 	
 	ex ndiff = this->derivative(s);
@@ -706,7 +698,7 @@ ex basic::eval_ncmul(const exvector & v) const
 struct derivative_map_function : public map_function {
 	const symbol &s;
 	derivative_map_function(const symbol &sym) : s(sym) {}
-	ex operator()(const ex & e) { return diff(e, s); }
+	ex operator()(const ex & e) override { return diff(e, s); }
 };
 
 /** Default implementation of ex::diff(). It maps the operation on the
@@ -753,7 +745,7 @@ bool basic::is_equal_same_type(const basic & other) const
  *  automatically used instead of match_same_type() if nops() == 0.
  *
  *  @see basic::match */
-bool basic::match_same_type(const basic &) const
+bool basic::match_same_type(const basic & /*unused*/) const
 {
 	// The default is to only consider subexpressions, but not any other
 	// attributes
@@ -776,16 +768,16 @@ tinfo_t basic::return_type_tinfo() const
  *  members.  For this reason it is well suited for container classes but
  *  atomic classes should override this implementation because otherwise they
  *  would all end up with the same hashvalue. */
-unsigned basic::calchash() const
+long basic::calchash() const
 {
-	unsigned v = golden_ratio_hash((p_int)tinfo());
+	long v = golden_ratio_hash((p_int)tinfo());
 	for (size_t i=0; i<nops(); i++) {
 		v = rotate_left(v);
 		v ^= this->op(i).gethash();
 	}
 
 	// store calculated hash value only if object is already evaluated
-	if (flags & status_flags::evaluated) {
+	if ((flags & status_flags::evaluated) != 0u) {
 		setflag(status_flags::hash_calculated);
 		hashvalue = v;
 	}
@@ -797,7 +789,7 @@ unsigned basic::calchash() const
 struct expand_map_function : public map_function {
 	unsigned options;
 	expand_map_function(unsigned o) : options(o) {}
-	ex operator()(const ex & e) { return e.expand(options); }
+	ex operator()(const ex & e) override { return e.expand(options); }
 };
 
 /** Expand expression, i.e. multiply it out and return the result as a new
@@ -827,8 +819,8 @@ int basic::compare(const basic & other) const
 #ifdef GINAC_COMPARE_STATISTICS
 	compare_statistics.total_basic_compares++;
 #endif
-	const unsigned hash_this = gethash();
-	const unsigned hash_other = other.gethash();
+	const long hash_this = gethash();
+	const long hash_other = other.gethash();
 	if (hash_this<hash_other) return -1;
 	if (hash_this>hash_other) return 1;
 #ifdef GINAC_COMPARE_STATISTICS
