@@ -696,7 +696,24 @@ void function::print(const print_context & c, unsigned level) const
 		Py_DECREF(args);
 	} else {
 
-		const function_options &opt = registered_functions()[serial];
+		if (is_a<print_latex>(c)) {
+		        PyObject* sfunc = py_funcs.py_get_sfunction_from_serial(serial);
+                        if (PyObject_HasAttrString(sfunc, "_print_latex_")) {
+                                PyObject* args = py_funcs.exvector_to_PyTuple(seq);
+                                std::string* sout;
+                                sout = py_funcs.py_latex_function(serial, args);
+                                if (PyErr_Occurred() != nullptr) {
+                                        throw(std::runtime_error("function::print(): python print function raised exception"));
+                                }
+                                c.s << *sout;
+                                c.s.flush();
+                                delete sout;
+                                Py_DECREF(args);
+                                return;
+                        }
+		}
+
+                const function_options &opt = registered_functions()[serial];
 		const std::vector<print_funcp> &pdt = opt.print_dispatch_table;
 
 
@@ -1530,7 +1547,6 @@ void function::set_domain(unsigned d)
                 case domain::positive:
                         iflags.set(info_flags::real, true);
                         iflags.set(info_flags::positive, true);
-                        iflags.set(info_flags::nonnegative, true);
                         break;
                 case domain::integer:
                         iflags.set(info_flags::real, true);
@@ -1561,7 +1577,7 @@ bool function::info(unsigned inf) const
                 case info_flags::positive:
                         return arg.info(info_flags::real) and
                                 is_exactly_a<numeric>(arg) and
-                                ex_to<numeric>(arg) >= *_num1_p;
+                                ex_to<numeric>(arg) > *_num1_p;
                 case info_flags::negative:
                         return arg.info(info_flags::real) and
                                 is_exactly_a<numeric>(arg) and
