@@ -1234,13 +1234,17 @@ expair mul::combine_ex_with_coeff_to_pair(const ex & e,
 expair mul::combine_pair_with_coeff_to_pair(const expair & p,
                                             const ex & c) const
 {
+        if (is_exactly_a<symbol>(p.rest))
+                return expair(p.rest, p.coeff*c);
+	if (c.is_integer_one())
+		return p;
+        if (p.coeff.is_integer_one())
+                return expair(p.rest, c);
+
 	// to avoid duplication of power simplification rules,
 	// we create a temporary power object
 	// otherwise it would be hard to correctly evaluate
 	// expression like (4^(1/3))^(3/2)
-	if (c.is_integer_one())
-		return p;
-
 	return split_ex_to_pair(power(recombine_pair_to_ex(p),c));
 }
 	
@@ -1558,4 +1562,23 @@ std::unique_ptr<epvector> mul::expandchildren(unsigned options) const
 	return std::unique_ptr<epvector>(nullptr); // nothing has changed
 }
 
+ex mul::without_known_factor(const ex& f) const
+{
+	epvector s;
+	s.reserve(seq.size()-1);
+
+        bool found = false;
+	for (const auto & elem : seq) {
+                ex t = recombine_pair_to_ex(elem);
+                if (not found and t.is_equal(f)) {
+                        found = true;
+                }
+                else
+			s.push_back(elem);
+	}
+
+	mul * result = new mul(s, ex_to<numeric>(overall_coeff));
+	return result->setflag(status_flags::dynallocated);
+}
+
 } // namespace GiNaC
