@@ -198,16 +198,13 @@ void symbol::set_domain(unsigned d)
                 case domain::positive:
                         iflags.set(info_flags::real, true);
                         iflags.set(info_flags::positive, true);
-                        iflags.set(info_flags::nonnegative, true);
                         break;
                 case domain::integer:
                         if(iflags.get(info_flags::positive)) {
                                 iflags.set(info_flags::positive, true);
-                                iflags.set(info_flags::nonnegative, true);
                         }
                         else {
                                 iflags.set(info_flags::positive, false);
-                                iflags.set(info_flags::nonnegative, false);
                         }
                         iflags.set(info_flags::real, true);
                         iflags.set(info_flags::integer, true);
@@ -262,7 +259,7 @@ ex symbol::real_part() const
 ex symbol::imag_part() const
 {
 	if (domain==domain::real || domain==domain::positive)
-		return 0;
+		return _ex0;
 	return imag_part_function(*this).hold();
 }
 
@@ -409,4 +406,28 @@ bool has_symbol(const ex & x)
 	return false;
 }
 
+bool has_symbol(const ex & x, const symbol& s)
+{
+	if (is_exactly_a<symbol>(x) and ex_to<symbol>(x) == s)
+		return true;
+	for (size_t i=0; i<x.nops(); ++i)
+		if (has_symbol(x.op(i), s))
+			return true;
+
+	return false;
+}
+
+bool has_free_symbol(const ex & x, const symbol& s)
+{
+        if (is_exactly_a<function>(x))
+                return false;
+	if (is_exactly_a<symbol>(x) and ex_to<symbol>(x) == s)
+		return true;
+	for (size_t i=0; i<x.nops(); ++i)
+		if (has_free_symbol(x.op(i), s))
+			return true;
+
+	return false;
+}
+
 } // namespace GiNaC
